unit SmartDongleTestUnit;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, mwi_sd, StdCtrls, ExtCtrls;

type
  TForm2 = class(TForm)
    lbLog: TListBox;
    Panel1: TPanel;
    Button1: TButton;
    edtKey1: TEdit;
    edtKey2: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Button1Click(Sender: TObject);
  private
    { Private declarations }
    sd: TmwiSmartDongle;
    ledColor: TsdLedColor;
    procedure ThreadSuccess;
    procedure ThreadError(ErrorCode: Integer; ErrorMsg: String);
    procedure TestStrings;
    procedure TestIntegers;
    procedure TestDoubles;
    procedure Log(s: string);
    procedure Busy;
    procedure Done;
    procedure TestFullEEPROM;
  public
    { Public declarations }
  end;

var
  Form2: TForm2;

implementation

{$R *.dfm}

function GetSysDir: string;
begin
  GetSystemDirectory(PChar(Result), MAX_PATH);
end;

function NewGuid: string;
var
  guid: TGUID;
begin
  CreateGUID(guid);
  result := GUIDToString(guid);
end;

procedure TForm2.Log(s: string);
begin
  lbLog.Items. Add(s);
  lbLog.Update;
  Application.ProcessMessages;
end;

procedure TForm2.Button1Click(Sender: TObject);
begin
  Button1.Enabled := False;
  sd.Key1 := edtKey1.Text;
  sd.Key2 := edtKey2.Text;
  sd.Authenticate;
  Log('Authenticated');
  Log('Version:');
  with sd.Version do
  begin
    Log(Format('  Major: %d', [dwMajorVersion]));
    Log(Format('  Minor: %d', [dwMinorVersion]));
    Log(Format('  Build: %d', [dwBuildNumber]));
    Log(Format('  Platform: %d', [dwPlatformID]));
  end;
  Log(Format('EEPROM Size: %d', [sd.EepromSize]));

  TestStrings;

  TestIntegers;

  TestDoubles;

  TestFullEEPROM;

  // Thread test
  sd.ThreadInterval := 1;
  sd.ThreadActive := True;
end;

procedure TForm2.FormCreate(Sender: TObject);
begin
  Randomize;
  sd := TmwiSmartDongle.Create(nil);
  sd.OnThreadSuccess := ThreadSuccess;
  sd.OnThreadError := ThreadError;
end;

procedure TForm2.FormDestroy(Sender: TObject);
begin
  sd.ThreadActive := False;
  sd.Free;
end;

procedure TForm2.ThreadSuccess;
begin
  if ledColor <= sdRed then
    inc(ledColor)
  else
    ledColor := sdNone;

  sd.SetLEDColor(ledColor);
  case ledColor of
    sdNone: Log('LED Off');
    sdGreen: Log('LED Green');
    sdRed: Log('LED Red');
  end;
end;

procedure TForm2.ThreadError(ErrorCode: Integer;
  ErrorMsg: String);
begin
   Log('Dongle is not present. Message: ' + ErrorMsg +
                   ' Error Code: ' + IntToStr( ErrorCode ));
end;

procedure TForm2.Busy;
begin
  sd.LEDRed;
  screen.Cursor := crHourGlass;
end;

procedure TForm2.Done;
begin
  screen.Cursor := crDefault;
  sd.LEDGreen;
end;

procedure TForm2.TestIntegers;
var
  val1, val2: integer;
begin
  Busy;
  try
    val1 := Random(MaxInt);
    Log(Format('Writing integer: %d', [val1]));
    sd.WriteInteger(0, val1);
    val2 := sd.ReadInteger(0);
    Log(Format('Read integer as: %d', [val2]));
    if val1 = val2 then
      Log('Match!')
    else
      Log('FAIL!');
  finally
    Done;
  end;
end;

procedure TForm2.TestStrings;
var
  val1, val2: string;
begin
  Busy;
  try
    val1 := NewGuid;
    if sizeof(char) = 1 then
      SetLength(val1, EEPROM_PAGE_SIZE - 1)
    else
      SetLength(val1, EEPROM_PAGE_SIZE div 2 - 1);
    Log(Format('Writing string: %s', [val1]));
    sd.WriteString(0, val1);
    val2 := sd.ReadString(0);
    Log(Format('Read string as: %s', [val2]));
    if val1 = val2 then
      Log('Match!')
    else
      Log('FAIL!');
  finally
    Done;
  end;
end;

procedure TForm2.TestDoubles;
var
  val1, val2: Double;
begin
  Busy;
  try
    val1 := Random;
    Log(Format('Writing double: %f', [val1]));
    sd.WriteDouble(0, val1);
    val2 := sd.ReadDouble(0);
    Log(Format('Read double as: %f', [val2]));
    if val1 = val2 then
      Log('Match!')
    else
      Log('FAIL!');
  finally
    Done;
  end;
end;

procedure TForm2.TestFullEEPROM;
var
  val1, val2, line: string;
  pages, page: integer;

begin
  Busy;
  try
    pages := sd.EepromSize div EEPROM_PAGE_SIZE - 1;
    log(Format('Writing %d pages.', [pages]));
    for page := 0 to pages do begin
      val1 := NewGuid;
      if sizeof(char) = 1 then
        SetLength(val1, EEPROM_PAGE_SIZE - 1)
      else
        SetLength(val1, EEPROM_PAGE_SIZE div 2 - 1);
      sd.WriteString(page, val1);
      val2 := sd.ReadString(page);
      line := Format('Round trip: %s = %s', [val1, val2]);
      if val1 = val2 then
        line := line + ' Match!'
      else
        line := line + ' FAIL!';
      Log(line);
    end;
  finally
    Done;
  end;
end;

end.
