{*******************************************************************************
  Copyright (c) MicroWorks Inc. 2003

  usk.pas

  Source for usk.dll interface.
********************************************************************************}
{ Maintenance
    fkr 082304 Backwards compatibility with original SmartDongle used with
               RegistWARE to date used with uskOld.dll in mwi_sd
}

unit usk;

interface
uses
   Windows;

const
   // Platform IDs for DLLVERSIONINFO
   USK_DLLVER_PLATFORM_WINDOWS = $00000001;      // Windows 95
   USK_DLLVER_PLATFORM_NT      = $00000002;      // Windows NT

   // Error Codes
   //***************************************************************************
   USK_OK                      = 0;

   // Can't open dongle
   USK_ERR_OPEN                = 1;

   // Dongle is already open.
   USK_ERR_IS_OPEN             = 2;

   // Memory allocation error
   USK_ERR_MEM                 = 3;

   // Address offset or buffer size exceeds EEPROM memory
   USK_ERR_EEPROM_SIZE         = 4;

   // Timeout waiting for state change
   USK_ERR_SECURITY_STATE_TIMEOUT = 6;

   // Timeout waiting for state change in
   // QTS-195 and Host Challenge handshake.
   USK_ERR_KEY_STATE_TIMEOUT                = 7;

   // Timeout waiting for TWC to reset
   USK_ERR_TWC_RESET_TIMEOUT                = 8;

   // Timeout waiting for task_loop to be flagged as inactive.
   USK_ERR_BUSY_TIMEOUT                     = 9;

   // The Dongle is Not in ENABLED Mode
   USK_ERR_NOT_ENABLED                      = 10;

   // Timeout Waiting For Read Flag(s) to be set
   USK_ERR_EEPROM_READ_TIMEOUT              = 11;

   // An EEPROM Read ERROR Occurred
   USK_ERR_EEPROM_READ                      = 12;

   // An EEPROM Write ERROR Occurred
   USK_ERR_EEPROM_WRITE                     = 13;

   // Dongle failed to validate against user keys
   USK_ERR_USK_VALIDATE                     = 14;

   // Host failed to validate against dongle keys
   USK_ERR_HOST_VALIDATE                    = 15;

   // An error occurred when attempting to disable QTS-195
   USK_ERR_DISABLE                          = 16;

   // Invalid P1 or P2 value passed in.
   USK_ERR_INVALID_KEYS                     = 17;


   // IOCTL's Failed: see qtsioctl.h
   USK_ERR_IOCTL_GET_PIPE_INFO              = 18;
   USK_ERR_IOCTL_GET_DEVICE_DESCRIPTOR      = 19;
   USK_ERR_IOCTL_GET_CONFIG_DESCRIPTOR      = 20;
   USK_ERR_IOCTL_REGISTER_NOTIFY_EVENT      = 21;
   USK_ERR_IOCTL_RESET_DEVICE               = 22;
   USK_ERR_IOCTL_RESET_PIPE                 = 23;
   USK_ERR_IOCTL_GET_DRIVER_REVISION        = 24;
   USK_ERR_IOCTL_GET_STRING_DESCRIPTOR      = 25;
   USK_ERR_IOCTL_IS_DONGLE_ALIVE            = 26;
   USK_ERR_IOCTL_SEND_KEY                   = 27;
   USK_ERR_IOCTL_GET_KEY                    = 28;
   USK_ERR_IOCTL_WRITE_PORT                 = 29;
   USK_ERR_IOCTL_READ_PORT                  = 30;
   USK_ERR_IOCTL_READ_EEPROM                = 31;
   USK_ERR_IOCTL_WRITE_EEPROM               = 32;
   USK_ERR_IOCTL_GET_SECURITY_STATE         = 33;
   USK_ERR_IOCTL_RESET_SECURITY_STATE       = 34;
   USK_ERR_IOCTL_GET_KEY_STATE              = 35;
   USK_ERR_IOCTL_RESET_KEY_STATE            = 36;
   USK_ERR_IOCTL_SEND_HOST_VERIFY_REQUEST   = 37;
   USK_ERR_IOCTL_REQUEST_PAGE               = 38;
   USK_ERR_IOCTL_GET_PAGE_FLAGS             = 39;
   USK_ERR_IOCTL_GET_TWC_FLAG               = 40;
   USK_ERR_IOCTL_GET_BUSY_FLAG              = 41;
   USK_ERR_IOCTL_GET_EEPROM_ERROR_FLAG      = 42;

   USK_ERR_UNKNOWN                          = 255;
   //***************************************************************************



type

   // Same structure as Shell DLLVersionInfo in shlwapi.h
   _USKDllVersionInfo = record
      cbSize: dword;
      dwMajorVersion: dword;
      dwMinorVersion: dword;
      dwBuildNumber: dword;
      dwPlatformID: dword;  // platform ID defined in USK_DLLVER_PLATFORM_WINDOWS or
                            // USK_DLLVER_PLATFORM_NT
   end; //_USKDllVersionInfo


   TuskGetVersion = function( var dvi: _USKDllVersionInfo ): integer; stdcall;

   TuskRead = function ( P1,
                         P2: Int64;
                         offset: dword;
                         buffer: PByte;
                         bufSize: Integer ): integer; stdcall;

   // fkr 082304 Backwards compatibility with original SmartDongle used with
   //            RegistWARE to date used with uskOld.dll in mwi_sd
   TuskReadOld = function ( P1,
                         P2: Int64;
                         offset: dword;
                         buffer: PByte;
                         bufSize: Integer ): integer; stdcall;

   TuskWrite = function ( P1,
                          P2: Int64;
                          offset: dword;
                          buffer: PByte;
                          bufSize: Integer ): integer; stdcall;

   // fkr 082304 Backwards compatibility with original SmartDongle used with
   //            RegistWARE to date used with uskOld.dll in mwi_sd
   TuskWriteOld = function ( P1,
                          P2: Int64;
                          offset: dword;
                          buffer: PByte;
                          bufSize: Integer ): integer; stdcall;

   TuskLEDGreen = function(): integer; stdcall;

   TuskLEDRed = function(): integer; stdcall;

   TuskLEDOff = function(): integer; stdcall;

   TuskEepromSize = function( P1,  P2: Int64): integer; stdcall;

implementation

end.

